capture log close sublog
log using "$prdir/log/analysis/qcew/synth_ctrl_nicegraphs_2013.txt", name(sublog) text replace

*-------------------------------------------------------------------------------
* Description: Make nice graphs of the 2013 - 2018 Orlando vs synthetic 
* control output data
* Author: Justin Wiltshire
	
* Updated: November 14, 2019
*-------------------------------------------------------------------------------

* Create the graphs
local naics "10 23 44 72" 
foreach ind of local naics {
	if `ind' == 10 {
		local ind_label "Total"
	}
	else if `ind' == 23 {
		local ind_label "Construction"
	}
	else if `ind' == 44 {
		local ind_label "Retail"
	}
	else if `ind' == 72 {
		local ind_label "Accomodation/food services"
	}
	foreach lhs in resid_ln_emp resid_ln_avg_wkly_wage resid_ln_wagebill resid_ln_estabs {
		use "$prdir/dta/analysis/qcew/sc_results_dta/cz_7400/`lhs'/deseasonalize_n`ind'_2013.dta", clear
		
		* Normalize things so Orlando is 0 at the beginning of the series
		qui gen x = _Y_treat[1]
		qui egen orl_0 = max(x)
		qui gen y_treat = _Y_treat - orl_0
		qui gen y_synth = _Y_synth - orl_0
		
		* Define the locals to use for the graph titles
		if "`lhs'" == "resid_ln_emp" {
			local var = "Log employment (residualized)"
			local var_label "employment"
		}
		else if "`lhs'" == "resid_ln_wagebill" {
			local var = "Log total compensation (residualized)"
			local var_label "compensation (total)"
		}
		else if "`lhs'" == "resid_ln_avg_wkly_wage" {
			local var = "Log compensation per worker (residualized)"
			local var_label "compensation per worker"
		}
		else if "`lhs'" == "resid_ln_estabs" {
			local var = "Log total establishments (residualized)"
			local var_label "establishments"
		}
			
		* Create the graphs
		tsset _time, monthly
		if "`lhs'" == "resid_ln_emp" {
			#delimit ;
				twoway 
					(line y_treat _time, lcolor(black)) || (line y_synth _time, lcolor(gs8) lp(dash)), 
					xline(691.5, lwidth(2) lcolor(gs12))
					xline(691 692, lp(dot) lcolor(gs8)) 
					xtitle("") ytitle("`var'")
					yscale(range(-0.05 0.6))
					ylabel(-0.1(0.1)0.6)
					graphregion(fcolor(white)) plotregion(fcolor(white)) bgcolor(white)
					legend(label(1 "Orlando") label(2 "Synthetic control"));
				#delimit cr
		}
		else if "`lhs'" != "resid_ln_emp" {
			#delimit ;
				twoway 
					(line y_treat _time, lcolor(black)) || (line y_synth _time, lcolor(gs8) lp(dash)), 
					xline(692.5, lwidth(6) lcolor(gs12))
					xline(691 694, lp(dot) lcolor(gs8)) 
					xtitle("") ytitle("`var'")
					yscale(range(-0.05 0.2))
					ylabel(-0.1(0.05)0.2)
					graphregion(fcolor(white)) plotregion(fcolor(white)) bgcolor(white)
					legend(label(1 "Orlando") label(2 "Synthetic control"));
				#delimit cr
		}
		nicepdf "$prdir/out/analysis/cz_7400/nice_graphs/synthetic_controls/sc_`lhs'_n`ind'_2013.pdf", replace
	}	
}
	
* Close the log file
log close sublog
