capture log close sublog
log using "$prdir/log/analysis/qwi/p_values.txt", name(sublog) text replace

*-------------------------------------------------------------------------------
* Description: Andrews and CWZ p-values tables
* Extended treated period (one year). Some states are missing obs
* Author: Justin Wiltshire
	
* Updated: August 1, 2020
*-------------------------------------------------------------------------------

* For treated unit (Orlando)
local treat_cz = 7400

*-------------------------------------------------------------------------------
* Make the tables
*-------------------------------------------------------------------------------

* Loop over the different QWI data sets
foreach dem in nonhisp hsorless {
			
		* Loop over the LHS variables
		foreach lhs in emp avg_wkly_wage {
						 
			* Loop over the NAICS supersectors
			foreach ind of numlist 10 23 44 72 {
			
			* Over six-month impacts
	forval z = 2(2)4 {
		local zz=`z'*3
						
				* Define the industry labels
				if "`ind'" == "10" {
					local industry "\textit{Aggregate}"
					local industry2 ""
				}
				else if "`ind'" == "23" {
					local industry "\textit{Construction}"
					local industry2 ""
				}
				else if "`ind'" == "44" {
					local industry "\textit{Retail}"
					local industry2 ""
				}
				else if "`ind'" == "72" {
					local industry "\textit{Hospitality}"
					local industry2 ""
				}
				
				* Load the Andrews p-value data
				qui use "$prdir/dta/analysis/qwi/`dem'/andrews_tests/resid_ln_`lhs'_ind`ind'_event_year_`z'1year.dta", clear
				
				* Put the key figures in a matrix
				if `z' == 2 {
					qui sum p, d
					mat andrewspval`ind'`lhs' = r(mean)
				}	
				if `z' == 4 {
					qui sum p, d
					mat andrewspval`ind'`lhs' = andrewspval`ind'`lhs', r(mean)
				}
						
				* Load the CWZ moving-block p-value data
				qui use "$prdir/dta/analysis/qwi/`dem'/moving_block_pval/resid_ln_`lhs'_ind`ind'_event_year_`z'1year.dta", clear
								
				* Put the key figures in a matrix
				if `z' == 2 {
					qui sum tr_effect, d
					mat effect`ind'`lhs' = r(mean)
					qui sum p, d
					mat pval`ind'`lhs' = r(mean)
					mat N`ind'`lhs' = 999
				}	
				if `z' == 4 {
					qui sum tr_effect, d
					mat effect`ind'`lhs' = effect`ind'`lhs', r(mean)
					qui sum p, d
					mat pval`ind'`lhs' = pval`ind'`lhs', r(mean)
					mat N`ind'`lhs' = N`ind'`lhs', 999
				}
								
				* Now make the tables *if* we've looped through to the last lhs variable (resid_ln_avg_wkly_wage)
				if "`lhs'" == "avg_wkly_wage" & `z' == 4 {
					
					* Combine the matrices into one
					mat vals`ind' = effect`ind'emp, effect`ind'`lhs'
					mat andrewspval`ind' = andrewspval`ind'emp, andrewspval`ind'`lhs'
					mat pval`ind' = pval`ind'emp, pval`ind'`lhs'
					mat pvals`ind' = andrewspval`ind'\pval`ind'
					mat N`ind' = N`ind'emp, N`ind'`lhs'
															
					* Make the combined tables
					frmttable using "$prdir/out/analysis/qwi/`dem'/cz_`treat_cz'/tables/combined/andrews_cwz_`dem'_naics_`ind'", replace tex statmat(vals`ind') sdec(4) ///
					ctitles("`industry'","Log","","Log Earnings",""\"`industry2'","Employment","","per Worker",""\"","6 month TE","12 month TE","6 month TE","12 month TE") ///
					rtitles("Treatment effect")
								
					frmttable using "$prdir/out/analysis/qwi/`dem'/cz_`treat_cz'/tables/combined/andrews_cwz_`dem'_naics_`ind'", replace tex statmat(pvals`ind') sdec(4) ///
					rtitles("Andrews \textit{p}-value"\"Moving block \textit{p}-value") append
								
					frmttable using "$prdir/out/analysis/qwi/`dem'/cz_`treat_cz'/tables/combined/andrews_cwz_`dem'_naics_`ind'", replace tex statmat(N`ind') sdec(0) ///
					rtitles("N") append
				}
			}
		}
	}
}

* Close the log file
log close sublog		
			
