capture log close sublog
log using "$prdir/log/check/maps_fema_cz.txt", name(sublog) text replace

*-------------------------------------------------------------------------------
* Description: Map FEMA applications by CZ. For the 48 contiguous states, only
* Author: Justin Wiltshire
	
* Updated: October 11, 2019
*-------------------------------------------------------------------------------

* Load the FEMA application by CZ data
use "$prdir/cw/geo/dta/cty_cz/cln/fema_cz.dta", clear
recode fema_apps (0=.)
recode pc_fema_apps (0 = 0.00000001) if fema_apps > 0 & fema_apps != .
recode pc_fema_apps (0=.)

* Create FEMA-applications-by-CZ maps
maptile fema_apps, geo(cz1990) conus ndfcolor(white) ///
 cutvalues (5 20 50 100 200) ///
 twopt(legend(pos(7) label(1 "No applications") label(2 "1 - 5") label(3 "5 - 20") label(4 "20 - 50") label(5 "50 - 100") label(6 "100 - 200") label(7 "200 - 3,792"))) ///
savegraph("$prdir/out/check/fema_apps/fema_cz.pdf") replace

maptile fema_apps, geo(cz1990) conus fcolor(Greys) ndfcolor(white) ///
 cutvalues (5 20 50 100 200) ///
 twopt(legend(pos(7) label(1 "No applications") label(2 "1 - 5") label(3 "5 - 20") label(4 "20 - 50") label(5 "50 - 100") label(6 "100 - 200") label(7 "200 - 3,792"))) ///
savegraph("$prdir/out/check/fema_apps/fema_cz_grey.pdf") replace

maptile fema_apps, geo(cz1990) conus ndfcolor(white) ///
 cutvalues (100 200 500 1457) ///
 twopt(legend(pos(7) label(1 "No applications") label(2 "< 100") label(3 "100 - 200") label(4 "200 - 500") label(5 "500 - 1,457") label(6 "3,972"))) ///
savegraph("$prdir/out/check/fema_apps/fema_cz_extremes.pdf") replace

maptile fema_apps, geo(cz1990) conus fcolor(Greys) ndfcolor(white) ///
 cutvalues (100 200 500 1457) ///
 twopt(legend(pos(7) label(1 "No applications") label(2 "< 100") label(3 "100 - 200") label(4 "200 - 500") label(5 "500 - 1,457") label(6 "3,972"))) ///
savegraph("$prdir/out/check/fema_apps/fema_cz_extremes_greys.pdf") replace

* Create per-capita FEMA-applications-by-CZ maps (extreme cuts)
maptile pc_fema_apps, geo(cz1990) conus ndfcolor(white) ///
 cutvalues (.00001 .00005 .0001 .0003) ///
 twopt(legend(pos(7) label(1 "No applications") label(2 "0 - 0.00001") label(3 "0.00001 - 0.00005") label(4 "0.00005 - 0.0001") label(5 "0.0001 - 0.0003") label(6 "0.0003+"))) ///
savegraph("$prdir/out/check/fema_apps/pc_fema_cz_extremes.pdf") replace

maptile pc_fema_apps, geo(cz1990) conus fcolor(Greys) ndfcolor(white) ///
 cutvalues (.00001 .00005 .0001 .0003) ///
 twopt(legend(pos(7) label(1 "No applications") label(2 "0 - 0.00001") label(3 "0.00001 - 0.00005") label(4 "0.00005 - 0.0001") label(5 "0.0001 - 0.0003") label(6 "0.0003+"))) ///
savegraph("$prdir/out/check/fema_apps/pc_fema_cz_extremes_greys.pdf") replace

* Create per-100,000 population FEMA-applications-by-CZ maps (extreme cuts)
qui gen phun_fema_apps = pc_fema_apps*100000
maptile phun_fema_apps, geo(cz1990) conus ndfcolor(white) ///
 cutvalues (10 25 50 100) ///
 twopt(legend(pos(7) label(1 "No applications") label(2 "< 10") label(3 "10 - 25") label(4 "25 - 50") label(5 "50 - 98") label(6 "178"))) ///
savegraph("$prdir/out/check/fema_apps/phun_fema_cz_extremes.pdf") replace

maptile phun_fema_apps, geo(cz1990) conus fcolor(Greys) ndfcolor(white) ///
 cutvalues (10 25 50 100) ///
 twopt(legend(pos(7) label(1 "No applications") label(2 "< 10") label(3 "10 - 25") label(4 "25 - 50") label(5 "50 - 98") label(6 "178"))) ///
savegraph("$prdir/out/check/fema_apps/phun_fema_cz_extremes_greys.pdf") replace

* Close the log file
log close sublog
