*-------------------------------------------------------------------------------
* Description: Master do file to run Hurricane Maria project
* Author: Justin Wiltshire
*
* Updated: April 20, 2022
*-------------------------------------------------------------------------------

* Run the settings file
do "/home/research/maria/do/settings.do" // Some font and graph settings require other files

*-------------------------------------------------------------------------------
* Build the data files
*-------------------------------------------------------------------------------

* Run src build files
do "$prdir/do/build/src/qcew_builder.do"
do "$prdir/do/build/src/qwi_builder.do"

* Run crosswalk files
do "$prdir/cw/geo/do/qcew_cty_to_cz.do"
do "$prdir/cw/geo/do/qcew_cty_to_cz_2013.do"
do "$prdir/cw/geo/do/qwi_cty_to_cz.do"
do "$prdir/cw/geo/do/fema_cty_to_cz.do"

* Run cln build files (deseasonalize)
do "$prdir/do/build/cln/deseasonalize_qcew_naics_cz.do"
do "$prdir/do/build/cln/deseasonalize_qcew_naics_cz_2013.do"
do "$prdir/do/build/cln/deseasonalize_qwi_naics_cz.do"
do "$prdir/do/build/cln/deseasonalize_qwi_naics_cz_6month.do"
do "$prdir/do/build/cln/zillow_cln.do"

*-------------------------------------------------------------------------------
* Summary maps and figures
*-------------------------------------------------------------------------------

* Make the FEMA applications maps
do "$prdir/do/check/fema/fema_maps_cz.do"

* Hispanic employment share
do "$prdir/do/check/emp_shr/hisp_orl_emp_shr_by_ind_q2.do"
do "$prdir/do/check/emp_shr/orl_emp_shr_by_ind.do"

*-------------------------------------------------------------------------------
* Run primary analyses and generate tables & figures
*-------------------------------------------------------------------------------

* QCEW
do "$prdir/do/analysis/qcew/synth_ctrls.do"
do "$prdir/do/analysis/qcew/placebo_synth_ctrls.do"
do "$prdir/do/analysis/qcew/merge_te.do"
do "$prdir/do/analysis/qcew/p_values.do"
do "$prdir/do/analysis/qcew/andrews_and_cwz_p_values.do"
do "$prdir/do/analysis/qcew/tables.do"
do "$prdir/do/analysis/qcew/synth_ctrl_nicegraphs.do"
do "$prdir/do/analysis/qcew/treatment_effect_nicegraphs.do"
do "$prdir/do/analysis/qcew/combined_final_graphs.do"
*** QCEW synthetic control donors maps and tables
do "$prdir/do/check/sc_donors/donor_maps.do"
do "$prdir/do/check/sc_donors/all_donor_pool_maps.do"
do "$prdir/do/check/sc_donors/donor_tables.do"

* QWI with CZs for counties observed a full 4 quarters post-Maria
do "$prdir/do/analysis/qwi/synth_ctrls.do" 
do "$prdir/do/analysis/qwi/placebo_synth_ctrls.do"
do "$prdir/do/analysis/qwi/merge_te.do" 
do "$prdir/do/analysis/qwi/p_values.do" 
do "$prdir/do/analysis/qwi/andrews_and_cwz_p_values.do"
do "$prdir/do/analysis/qwi/andrews_cwz_p_values_tables.do"

*-------------------------------------------------------------------------------
* Robustness checks
*-------------------------------------------------------------------------------

* QWI with CZs for full sample of counties, only observed 2 quarters post-Maria
do "$prdir/do/analysis/qwi/6month/synth_ctrls.do"
do "$prdir/do/analysis/qwi/6month/placebo_synth_ctrls.do"
do "$prdir/do/analysis/qwi/6month/merge_te.do"
do "$prdir/do/analysis/qwi/6month/p_values.do"
do "$prdir/do/analysis/qwi/6month/alt_p_values.do"

* QCEW with the pre-treatment period extended to 2013
do "$prdir/do/analysis/qcew/2013_2018_robustness_check/synth_ctrls_2013.do"
do "$prdir/do/analysis/qcew/2013_2018_robustness_check/placebo_synth_ctrls_2013.do"
do "$prdir/do/analysis/qcew/2013_2018_robustness_check/merge_te_2013.do"
do "$prdir/do/analysis/qcew/2013_2018_robustness_check/p_values_2013.do"
do "$prdir/do/analysis/qcew/2013_2018_robustness_check/synth_ctrl_nicegraphs_2013.do"
do "$prdir/do/analysis/qcew/2013_2018_robustness_check/treatment_effect_nicegraphs_2013.do"

* Difference in differences 
do "$prdir/do/analysis/qcew/dd.do"

* Effect of Irma on Jacksonville overall and in construction (synthetic controls run in do "$prdir/do/analysis/qcew/synth_ctrls.do")
do "$prdir/do/analysis/qcew/irma_cz_p_values.do"

* 3 and 5 most treated CZs
do "$prdir/do/analysis/qcew/oth_treat_synth_ctrls.do" 
do "$prdir/do/analysis/qcew/oth_placebo_synth_ctrls.do"
do "$prdir/do/analysis/qcew/oth_sample_placebo_averages.do"
do "$prdir/do/analysis/qcew/oth_alt_p_values.do"
do "$prdir/do/analysis/qcew/oth_tables.do"
do "$prdir/do/analysis/qcew/distn_treatment_effect_nicegraphs.do"

* House prices/Zillow
do "$prdir/do/analysis/zillow/zillow_analyses.do"
