*-------------------------------------------------------------------------------
* Description: Settings for Puerto Rico Immigration/Hurricane Maria project
* Author: Justin Wiltshire
*
* Updated: April 18, 2022
*-------------------------------------------------------------------------------

* Set project directory macro
global prdir "/home/research/maria"

* Make key directories (a few are assumed already made. Creates some superfluous ones)
capture mkdir "$prdir/log"
capture mkdir "$prdir/log/cw"
capture mkdir "$prdir/log/build"
capture mkdir "$prdir/log/build/qcew"
capture mkdir "$prdir/log/build/qwi"
capture mkdir "$prdir/log/check"
capture mkdir "$prdir/log/analysis"
capture mkdir "$prdir/log/analysis/qcew"
capture mkdir "$prdir/log/analysis/qwi"
capture mkdir "$prdir/dta"
capture mkdir "$prdir/dta/check"
capture mkdir "$prdir/dta/src"
capture mkdir "$prdir/dta/src/qcew"
capture mkdir "$prdir/dta/src/qcew/cbk"
capture mkdir "$prdir/dta/src/qcew/zip"
capture mkdir "$prdir/dta/src/qwi"
capture mkdir "$prdir/dta/src/zillow"
capture mkdir "$prdir/dta/cln"
capture mkdir "$prdir/dta/cln/qcew"
capture mkdir "$prdir/dta/cln/qcew/cbk"
capture mkdir "$prdir/dta/cln/qcew/zip"
capture mkdir "$prdir/dta/cln/qcew/byyear"
capture mkdir "$prdir/dta/cln/qwi"
capture mkdir "$prdir/dta/cln/zillow"
capture mkdir "$prdir/dta/analysis"
capture mkdir "$prdir/dta/analysis/qcew"
capture mkdir "$prdir/dta/analysis/qwi"
capture mkdir "$prdir/out"
capture mkdir "$prdir/out/analysis"
capture mkdir "$prdir/out/analysis/cz_7400"
capture mkdir "$prdir/out/analysis/cz_7600"
capture mkdir "$prdir/out/analysis/cz_7400/tables"
capture mkdir "$prdir/out/analysis/cz_7400/tables/6_month"
capture mkdir "$prdir/out/analysis/cz_7400/tables/12_month"
capture mkdir "$prdir/out/analysis/cz_7400/tables/combined"
capture mkdir "$prdir/out/analysis/cz_7400/tables/DD"
capture mkdir "$prdir/out/analysis/cz_7600/tables"
capture mkdir "$prdir/out/analysis/cz_7600/tables/6_month"
capture mkdir "$prdir/out/analysis/cz_7600/tables/12_month"
capture mkdir "$prdir/out/analysis/cz_7600/tables/combined"
capture mkdir "$prdir/out/analysis/qwi"
capture mkdir "$prdir/out/analysis/zillow"
capture mkdir "$prdir/out/analysis/att"
capture mkdir "$prdir/out/check"
capture mkdir "$prdir/out/check/emp_shr"
capture mkdir "$prdir/out/check/fema_apps"
capture mkdir "$prdir/out/check/sc_weight_maps"
capture mkdir "$prdir/out/check/sc_weight_tables"
forval c = 7400(200)7600 {
	capture mkdir "$prdir/out/analysis/cz_`c'/nice_graphs"
	capture mkdir "$prdir/out/analysis/cz_`c'/nice_graphs/combined"
	capture mkdir "$prdir/out/analysis/cz_`c'/nice_graphs/synthetic_controls"
	capture mkdir "$prdir/out/analysis/cz_`c'/nice_graphs/te"
	capture mkdir "$prdir/out/analysis/cz_`c'/nice_graphs/te_alternate"
	foreach n in 10 23 44 72 {
		capture mkdir "$prdir/out/analysis/cz_`c'/naics_`n'"
	}
	foreach s in sc_results_dta sc_placebo_tests sc_merged sc_pvalue andrews_tests moving_block_pval placebo_averages distribution {
		capture mkdir "$prdir/dta/analysis/qcew/`s'"
		foreach lhs in resid_ln_emp resid_ln_avg_wkly_wage resid_ln_wagebill resid_ln_estabs {
			capture mkdir "$prdir/dta/analysis/qcew/`s'/cz_`c'/`lhs'"
			capture mkdir "$prdir/dta/analysis/qcew/`s'/cz_`c'/`lhs'/top3"
			capture mkdir "$prdir/dta/analysis/qcew/`s'/cz_`c'/`lhs'/top5"
		}
	}
	capture mkdir "$prdir/dta/analysis/qcew/moving_block_pval/att"
	capture mkdir "$prdir/dta/analysis/qcew/moving_block_pval/att3"
	foreach s in sc_results_dta sc_placebo_tests sc_merged sc_pvalue andrews_tests moving_block_pval placebo_averages {
		foreach cz in cz_7400 cz_7600 avg_oth_treat {
			capture mkdir "$prdir/dta/analysis/qcew/`s'/`cz'"
			if "`cz'" != "avg_oth_treat" {
				foreach lhs in resid_ln_emp resid_ln_avg_wkly_wage resid_ln_wagebill resid_ln_estabs {
					capture mkdir "$prdir/dta/analysis/qcew/`s'/`cz'/`n'/`lhs'"
				}
			}
			foreach n in 10 23 44 72 {
				if "`cz'" == "avg_oth_treat" {
					capture mkdir "$prdir/dta/analysis/qcew/`s'/`cz'/`n'"
					foreach lhs in resid_ln_emp resid_ln_avg_wkly_wage resid_ln_wagebill resid_ln_estabs {
						capture mkdir "$prdir/dta/analysis/qcew/`s'/`cz'/`n'/`lhs'"
						capture mkdir "$prdir/dta/analysis/qcew/`s'/`cz'/`n'/`lhs'/average"
						capture mkdir "$prdir/dta/analysis/qcew/`s'/`cz'/`n'/`lhs'/average3"
					}
				}
			}
		}
	}
}
capture mkdir "$prdir/dta/analysis/qcew/moving_block_pval/att"
foreach q in hsorless lessthanhs nonhisp nonhisp_white somecollplus {
	capture mkdir "$prdir/dta/analysis/qwi/`q'"
	capture mkdir "$prdir/out/analysis/qwi/`q'"
	capture mkdir "$prdir/out/analysis/qwi/`q'/cz_7400"
	foreach s in sc_results_dta sc_placebo_tests sc_merged sc_pvalue andrews_tests moving_block_pval placebo_averages distribution {
		capture mkdir "$prdir/dta/analysis/qwi/`q'/`s'"
		capture mkdir "$prdir/dta/analysis/qwi/`q'/`s'/cz_7400"
		foreach lhs in resid_ln_emp resid_ln_avg_wkly_wage resid_ln_wagebill resid_ln_estabs {
			capture mkdir "$prdir/dta/analysis/qwi/`q'/`s'/cz_7400/`lhs'"
		}
	}
}

* General graph appearance
set scheme lycidas1, permanently

* Fonts
graph set ps fontdir "$prdir/do/ado/fonts"
graph set eps fontdir "$prdir/do/ado/fonts"
graph set window fontface "CMU Serif"
graph set ps fontface "CMU Serif"
graph set ps fontfaceserif "CMU Serif"
graph set eps fontface "CMU Serif"
graph set eps fontfaceserif "CMU Serif"

* Specify color choices
global col1 "sea"
global col2 "cranberry"
global col3 "turquoise"
global col4 "vermillion"
global col5 "sky"
global col6 "sienna"
global col7 "purple"
global col8 "reddish"

* Grayscale
global gs "gs10"

* Line patterns
global pat1 "solid"
global pat2 "dash"
global pat3 "shortdash"
global pat4 "dash_dot"
global pat5 "solid"
global pat6 "dash"
global pat7 "shortdash"
global pat8 "dash_dot"

* Specify marker styles
global sym1 "circle"
global sym2 "diamond"
global sym3 "triangle"
global sym4 "square"
global sym5 "plus"
global sym6 "smcircle"
global sym7 "smdiamond"
global sym8 "smsquare"

* Miscellaneous
global pdfmargins = 2

* Sizing factor for paper and for slides: one-pane vs. two-pane figures
global paperscale1 = 1.00
global paperscale2 = 1.10
global slidescale1 = 1.10
global slidescale2 = 1.15

* Program to save graphs (by Brendan Price)
capture program drop nicepdf
program define nicepdf
	tempfile niceeps
	graph export "`niceeps'", as(eps) replace
	!epstopdf --outfile="`1'" "`niceeps'"
end

* Define the program to re-map 1990-onward counties into 1990 counties
*	SOURCE: https://www.ddorn.net/data/FIPS_County_Code_Changes.pdf (09/14/19)
*	NOTES:	*** Ignore Alaskan changes or changes with no action necessary to 
*			later map counties into 1990 CZs ***

capture program drop cty_remap
program define cty_remap

	* Confirm cty_fips variable is in memory
	confirm variable cty_fips
	
	* Recode Miami-Dade County, FL
	replace cty_fips = 12025 if cty_fips == 12086

	* Combine Broomfield and Boulder Counties, CO
	replace cty_fips = 08013 if cty_fips == 08014

	* Combine Shannon Oglala Lakota Counties, SD
	replace cty_fips = 46113 if cty_fips == 46102
end
	
* Create a macro of CZs to drop (pc FEMA applications >= .0001)
* Preserve any in-use data
preserve

* Load the FEMA data
qui use "$prdir/cw/geo/dta/cty_cz/cln/fema_cz.dta", clear
	
* Sort the FEMA applications
qui gsort -fema_apps
	
* Capture the CZs with >= .0001 applications per capita
levelsof(cz) if pc_fema_apps >= .0001, local(cz_list)
	
* Place in a global macro with CZs separated by commas
global cz_droplist = "7000 "
foreach c of local cz_list {
	if !inlist(`c', 7000, 7400) {
		global cz_droplist = "$cz_droplist, `c'"
	}
}

* Capture the top-five treated CZs EXCEPT Orlando
qui gsort -pc_fema_apps
levelsof cz if _n <= 5 & cz != 7400, local(cz_list)
gettoken cz_first cz_list : cz_list
global other_treated_cz = "`cz_first'"
foreach c of local cz_list {
	global other_treated_cz = "$other_treated_cz `c'"
}

* Capture the top-three treated CZs EXCEPT Orlando
qui gsort -pc_fema_apps
levelsof cz if _n <= 3 & cz != 7400, local(cz_list3)
gettoken cz_first cz_list3 : cz_list3
global top3_treated_cz = "`cz_first'"
foreach c of local cz_list3 {
	global top3_treated_cz = "$top3_treated_cz `c'"
}

* Capture the top-ten treated CZs EXCEPT Orlando
qui gsort -pc_fema_apps
levelsof cz if _n <= 10 & cz != 7400, local(cz_list10)
gettoken cz_first cz_list10 : cz_list10
global top10_treated_cz = "`cz_first'"
foreach c of local cz_list10 {
	global top10_treated_cz = "$top10_treated_cz `c'"
}

* Capture the top six-ten treated CZs
qui gsort -pc_fema_apps
levelsof cz if inrange(_n, 6, 10), local(cz_list610)
gettoken cz_first cz_list610 : cz_list610
global top610_treated_cz = "`cz_first'"
foreach c of local cz_list610 {
	global top610_treated_cz = "$top610_treated_cz `c'"
}

* Restore any in-use data
restore

* Program to concatenate pdfs (by Brendan Price)
capture program drop combine_pdfs
program define combine_pdfs
	syntax anything(name=filelist) using/[, replace delete]
	
	* Make sure that "anything" is non-empty
	capture assert `"`filelist'"' != ""
	if _rc != 0 {
		di as error "you must supply at least one .pdf name"
	}
	
	* If replace is not specified, output file must be new
	if "`replace'" == "" {
		confirm new file `using'
	}
	
	* Combine the input files into a single pdf
	shell gs -q -sPAPERSIZE=letter -dNOPAUSE -dBATCH -dAutoRotatePages=/None -sDEVICE=pdfwrite -sOutputFile=`using' `filelist'
	
	* If requested, delete the input files
	if "`delete'" != "" {
		foreach f in `filelist' {
			capture rm `f'
		}
	}
end

* Program to calculate stars indicating significance
capture program drop starmat
program starmat
	#delimit ;
		mat 
			`1' =
			(abs(`2') > invttail(`3',0.10/2)) +
			(abs(`2') > invttail(`3',0.05/2)) +
			(abs(`2') > invttail(`3',0.01/2));
		#delimit cr
end
